@@ -8,6 +8,7 @@
 Main file containing the mito widget.
 """
 import json
+import os
 import time
 from typing import Any, Dict, List, Optional, Union
 
@@ -20,18 +21,25 @@ from mitosheet.api import API
 from mitosheet.data_in_mito import DataTypeInMito
 from mitosheet.errors import (MitoError, get_recent_traceback,
                               make_execution_error)
+from mitosheet.mito_config import MitoConfig
 from mitosheet.saved_analyses import write_analysis
 from mitosheet.steps_manager import StepsManager
-from mitosheet.telemetry.telemetry_utils import (log, log_event_processed,
+from mitosheet.telemetry.telemetry_utils import (MITOSHEET_HELPER_PRIVATE, log, log_event_processed,
                                                  telemetry_turned_on)
 from mitosheet.updates.replay_analysis import REPLAY_ANALYSIS_UPDATE
 from mitosheet.user import is_local_deployment, should_upgrade_mitosheet
-from mitosheet.user.db import get_user_field
+from mitosheet.user.create import try_create_user_json_file
+from mitosheet.user.db import USER_JSON_PATH, get_user_field
 from mitosheet.user.location import is_in_google_colab, is_in_vs_code
-from mitosheet.user.schemas import (UJ_MITOSHEET_LAST_FIFTY_USAGES,
+from mitosheet.user.schemas import (UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_RECEIVED_CHECKLISTS,
                                     UJ_RECEIVED_TOURS, UJ_USER_EMAIL)
 from mitosheet.user.utils import is_excel_import_enabled, is_pro, is_running_test
 
+try:
+    from mitosheet_helper_config import MITO_ENTERPRISE_CONFIGURATION 
+except ImportError:
+    MITO_ENTERPRISE_CONFIGURATION = None
+
 
 class MitoWidget(DOMWidget):
     """
@@ -60,6 +68,8 @@ class MitoWidget(DOMWidget):
         # Set up the state container to hold private widget state
         self.steps_manager = StepsManager(args, analysis_to_replay=analysis_to_replay)
 
+        self.mito_config = MitoConfig(MITO_ENTERPRISE_CONFIGURATION)
+
         # Set up message handler
         self.on_msg(self.receive_message)
 
@@ -94,6 +104,7 @@ class MitoWidget(DOMWidget):
             # Dynamic, update each time
             'userEmail': get_user_field(UJ_USER_EMAIL),
             'receivedTours': get_user_field(UJ_RECEIVED_TOURS),
+            'receivedChecklists': get_user_field(UJ_RECEIVED_CHECKLISTS),
             'isPro': is_pro(),
             'telemetryEnabled': telemetry_turned_on(),
             # Static over a single analysis
@@ -101,6 +112,7 @@ class MitoWidget(DOMWidget):
             'isLocalDeployment': self.is_local_deployment,
             'shouldUpgradeMitosheet': self.should_upgrade_mitosheet,
             'numUsages': self.num_usages,
+            'mitoConfig': self.mito_config.get_mito_config()
         })
 
 
@@ -149,12 +161,17 @@ class MitoWidget(DOMWidget):
 
             # Update all state variables
             self.update_shared_state_variables()
-        except:
+        except Exception as e:
             # We handle the case of replaying the analysis specially, because we don't
             # want to display the error modal - we want to display something specific
             # in this case. Note that we include the updating of shared state variables
             # in the try catch, as this is sometimes where errors occur
             if event["type"] == REPLAY_ANALYSIS_UPDATE['event_type']:
+                # Propagate the Mito error if we can. We never want a replay analysis to open
+                # an error modal, so make sure to update the error if necessary
+                if isinstance(e, MitoError):
+                    e.error_modal = False
+                    raise e
                 raise make_execution_error(error_modal=False)
             raise
         # Also, write the analysis to a file!
@@ -286,6 +303,12 @@ def sheet(
         log('mitosheet_sheet_call_location_failed', failed=True)
         raise Exception("The mitosheet currently only works in JupyterLab.\n\nTo see instructions on getting Mitosheet running in JupyterLab, find install instructions here: https://docs.trymito.io/getting-started/installing-mito")
 
+    # If the user.json does not exist, we create it. This ensures if the file is deleted in between
+    # when the package is imported and mitosheet.sheet is called, the user still gets a user.json. 
+    # We don't need to upgrade as creating the file will automatically use the most recent version
+    if not os.path.exists(USER_JSON_PATH):
+        try_create_user_json_file()
+
     try:
         # We pass in the dataframes directly to the widget
         widget = MitoWidget(*args, analysis_to_replay=analysis_to_replay) 
