@@ -41,7 +41,7 @@ from mitosheet.step_performers.transpose import TransposeStepPerformer
 from mitosheet.step_performers.melt import MeltStepPerformer
 from mitosheet.step_performers.one_hot_encoding import OneHotEncodingStepPerformer
 from mitosheet.step_performers.set_dataframe_format import SetDataframeFormatStepPerformer
-from mitosheet.step_performers.dataframe_import import DataframeImportStepPerformer
+from mitosheet.step_performers.import_steps.dataframe_import import DataframeImportStepPerformer
 # AUTOGENERATED LINE: IMPORT (DO NOT DELETE)
 
 # All steps must be listed in this variable. Note the Type annotation allows for
