@@ -4,6 +4,7 @@
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
 from mitosheet.data_in_mito import DataTypeInMito
+from mitosheet.mito_config import DEFAULT_SUPPORT_EMAIL, MEC_CONFIG_KEY_SUPPORT_EMAIL, MEC_CONFIG_KEY_VERSION, MitoConfig
 from mitosheet.state import (
     DATAFRAME_SOURCE_DUPLICATED,
     DATAFRAME_SOURCE_IMPORTED,
@@ -193,3 +194,23 @@ def test_graph_safety_filter_cutoff_matches():
     )
 
     assert int(graph_safety_filter_cutoff) == GRAPH_SAFETY_FILTER_CUTOFF
+
+def test_mito_enterprise_keys_match():
+    mito_enterprise_config_keys = get_enum_from_ts_file("./src/types.tsx", "MitoEnterpriseConfigKey")
+    assert set(mito_enterprise_config_keys.values()) == set(MitoConfig(None).get_mito_config().keys())
+
+def test_user_profile_defaults_matches():
+    user_profile_support_email = get_constant_from_ts_file(
+        "./src/components/elements/GetSupportButton.tsx",
+        'DEFAULT_SUPPORT_EMAIL'
+    )
+
+    assert user_profile_support_email == f"\'{DEFAULT_SUPPORT_EMAIL}\'"
+
+def test_update_events_enum_defined():
+    update_types = get_enum_from_ts_file("./src/types.tsx", "UpdateType")
+    from mitosheet.updates import UPDATES
+
+    for UPDATE in UPDATES:
+        assert UPDATE['event_type'] in update_types.values()
+
