@@ -11,9 +11,9 @@ import json
 from functools import wraps
 from typing import Any, Dict, List, Optional, Tuple, Union
 from mitosheet.code_chunks.code_chunk_utils import get_code_chunks
-from mitosheet.step_performers.dataframe_import import get_variable_with_name_from_caller
+from mitosheet.step_performers.import_steps.dataframe_import import get_variable_with_name_from_caller
 from mitosheet.step_performers.graph_steps.plotly_express_graphs import DO_NOT_CHANGE_PAPER_BGCOLOR_DEFAULT, DO_NOT_CHANGE_PLOT_BGCOLOR_DEFAULT, DO_NOT_CHANGE_TITLE_FONT_COLOR_DEFAULT
-from numpy import bool_, number
+from numpy import number
 
 import pandas as pd
 from mitosheet.mito_widget import MitoWidget, sheet
@@ -746,11 +746,11 @@ class MitoWidgetTestWrapper:
         )
 
     @check_transpiled_code_after_call
-    def change_column_dtype(self, sheet_index: int, column_header: ColumnHeader, new_dtype: str) -> bool:
+    def change_column_dtype(self, sheet_index: int, column_headers: List[ColumnHeader], new_dtype: str) -> bool:
 
-        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+        column_ids = self.mito_widget.steps_manager.curr_step.column_ids.get_column_ids_by_headers(
             sheet_index,
-            column_header
+            column_headers
         )
 
         return self.mito_widget.receive_message(
@@ -762,7 +762,7 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id(),
                 'params': {
                     'sheet_index': sheet_index,
-                    'column_id': column_id,
+                    'column_ids': column_ids,
                     'new_dtype': new_dtype
                 }
             }
@@ -940,7 +940,7 @@ class MitoWidgetTestWrapper:
         )
 
     @check_transpiled_code_after_call
-    def replay_analysis(self, analysis_name: str) -> bool:
+    def replay_analysis(self, analysis_name: str, step_import_data_list_to_overwrite: List[Dict[str, Any]]=None) -> bool:
         return self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -949,6 +949,7 @@ class MitoWidgetTestWrapper:
                 'type': 'replay_analysis_update',
                 'params': {
                     'analysis_name': analysis_name,
+                    'step_import_data_list_to_overwrite': step_import_data_list_to_overwrite if step_import_data_list_to_overwrite is not None else []
                 },
             }
         )
@@ -1176,6 +1177,18 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    def update_existing_imports(self, updated_import_objs: List[Dict[str, Any]]) -> bool:
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'update_event',
+                'type': 'update_existing_import_update',
+                'id': get_new_id(),
+                'params': {
+                    'updated_step_import_data_list': updated_import_objs
+                }
+            }
+        )
 
     def get_formula(self, sheet_index: int, column_header: ColumnHeader) -> str:
         """
